@@ -1,14 +1,3 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-from builtins import str
-import warnings
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore")
-    from future import standard_library
-standard_library.install_aliases()
-from builtins import object
 import json
 from typing import Any
 from typing import AnyStr
@@ -35,12 +24,12 @@ API_ROOT_IAM_CREDENTIALS = 'https://iamcredentials.googleapis.com/v1'
 SCOPES = ['https://www.googleapis.com/auth/iam']
 
 
-class IamClient(object):
+class IamClient:
     def __init__(
-        self, service_file                                   = None,
-        session                    = None,
-        token                  = None,
-    )        :
+        self, service_file: Optional[Union[str, IO[AnyStr]]] = None,
+        session: Optional[Session] = None,
+        token: Optional[Token] = None,
+    ) -> None:
         self.session = SyncSession(session)
         self.token = token or Token(
             service_file=service_file, scopes=SCOPES,
@@ -56,25 +45,25 @@ class IamClient(object):
                 'with Service Accounts or GCE Metadata',
             )
 
-    def headers(self)                  :
+    def headers(self) -> Dict[str, str]:
         token = self.token.get()
         return {
-            'Authorization': 'Bearer {}'.format((token)),
+            'Authorization': f'Bearer {token}',
         }
 
     @property
-    def service_account_email(self)                 :
+    def service_account_email(self) -> Optional[str]:
         return self.token.service_data.get('client_email')
 
     # https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts.keys/get
     def get_public_key(
-        self, key_id                = None,
-        key                = None,
-        service_account_email                = None,
-        project                = None,
-        session                    = None,
-        timeout      = 10,
-    )                  :
+        self, key_id: Optional[str] = None,
+        key: Optional[str] = None,
+        service_account_email: Optional[str] = None,
+        project: Optional[str] = None,
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Dict[str, str]:
         service_account_email = (
             service_account_email
             or self.service_account_email
@@ -86,27 +75,27 @@ class IamClient(object):
 
         if not key:
             key = (
-                'projects/{}/serviceAccounts/'
-                '{}/keys/{}'.format((project), (service_account_email), (key_id))
+                f'projects/{project}/serviceAccounts/'
+                f'{service_account_email}/keys/{key_id}'
             )
 
-        url = '{}/{}?publicKeyType=TYPE_X509_PEM_FILE'.format((API_ROOT_IAM), (key))
+        url = f'{API_ROOT_IAM}/{key}?publicKeyType=TYPE_X509_PEM_FILE'
         headers = self.headers()
 
         s = SyncSession(session) if session else self.session
 
         resp = s.get(url=url, headers=headers, timeout=timeout)
 
-        data                 = resp.json()
+        data: Dict[str, str] = resp.json()
         return data
 
     # https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts.keys/list
     def list_public_keys(
-            self, service_account_email                = None,
-            project                = None,
-            session                    = None,
-            timeout      = 10,
-    )                        :
+            self, service_account_email: Optional[str] = None,
+            project: Optional[str] = None,
+            session: Optional[Session] = None,
+            timeout: int = 10,
+    ) -> List[Dict[str, str]]:
         service_account_email = (
             service_account_email
             or self.service_account_email
@@ -114,8 +103,8 @@ class IamClient(object):
         project = project or self.token.get_project()
 
         url = (
-            '{}/projects/{}/'
-            'serviceAccounts/{}/keys'.format((API_ROOT_IAM), (project), (service_account_email))
+            f'{API_ROOT_IAM}/projects/{project}/'
+            f'serviceAccounts/{service_account_email}/keys'
         )
 
         headers = self.headers()
@@ -124,17 +113,17 @@ class IamClient(object):
 
         resp = s.get(url=url, headers=headers, timeout=timeout)
 
-        data                       = (resp.json()).get('keys', [])
+        data: List[Dict[str, Any]] = (resp.json()).get('keys', [])
         return data
 
     # https://cloud.google.com/iam/credentials/reference/rest/v1/projects.serviceAccounts/signBlob
     def sign_blob(
-        self, payload                             ,
-        service_account_email                = None,
-        delegates                      = None,
-        session                    = None,
-        timeout      = 10,
-    )                  :
+        self, payload: Optional[Union[str, bytes]],
+        service_account_email: Optional[str] = None,
+        delegates: Optional[List[str]] = None,
+        session: Optional[Session] = None,
+        timeout: int = 10,
+    ) -> Dict[str, str]:
         service_account_email = (
             service_account_email
             or self.service_account_email
@@ -145,8 +134,8 @@ class IamClient(object):
                 'service_account_email',
             )
 
-        resource_name = 'projects/-/serviceAccounts/{}'.format((service_account_email))
-        url = '{}/{}:signBlob'.format((API_ROOT_IAM_CREDENTIALS), (resource_name))
+        resource_name = f'projects/-/serviceAccounts/{service_account_email}'
+        url = f'{API_ROOT_IAM_CREDENTIALS}/{resource_name}:signBlob'
 
         json_str = json.dumps({
             'delegates': delegates or [resource_name],
@@ -165,14 +154,14 @@ class IamClient(object):
             url=url, data=json_str, headers=headers,
             timeout=timeout,
         )
-        data                 = resp.json()
+        data: Dict[str, Any] = resp.json()
         return data
 
-    def close(self)        :
+    def close(self) -> None:
         self.session.close()
 
-    def __enter__(self)               :
+    def __enter__(self) -> 'IamClient':
         return self
 
-    def __exit__(self, *args     )        :
+    def __exit__(self, *args: Any) -> None:
         self.close()
