@@ -1,13 +1,3 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-import warnings
-with warnings.catch_warnings():
-    warnings.simplefilter("ignore")
-    from future import standard_library
-standard_library.install_aliases()
-from builtins import object
 import logging
 import threading
 from abc import ABCMeta
@@ -34,71 +24,71 @@ else:
 log = logging.getLogger(__name__)
 
 
-class BaseSession(object):
+class BaseSession:
     __metaclass__ = ABCMeta
 
     def __init__(
-        self, session                    = None, timeout        = 10,
-        verify_ssl       = True,
-    )        :
+        self, session: Optional[Session] = None, timeout: float = 10,
+        verify_ssl: bool = True,
+    ) -> None:
         self._shared_session = bool(session)
         self._session = session
         self._ssl = verify_ssl
         self._timeout = timeout
 
     @abstractproperty  # pylint: disable=deprecated-decorator
-    def session(self)                     :
+    def session(self) -> Optional[Session]:
         return self._session
 
     @abstractmethod
     def post(
-        self, url     , headers                   ,
-        data                                         , timeout       ,
-        params                                         ,
-    )            :
+        self, url: str, headers: Mapping[str, str],
+        data: Optional[Union[bytes, str, IO[AnyStr]]], timeout: float,
+        params: Optional[Mapping[str, Union[int, str]]],
+    ) -> Response:
         pass
 
     @abstractmethod
     def get(
-        self, url     , headers                             ,
-        timeout       , params                                         ,
-        stream      ,
-    )            :
+        self, url: str, headers: Optional[Mapping[str, str]],
+        timeout: float, params: Optional[Mapping[str, Union[int, str]]],
+        stream: bool,
+    ) -> Response:
         pass
 
     @abstractmethod
     def patch(
-        self, url     , headers                   ,
-        data                             , timeout       ,
-        params                                         ,
-    )            :
+        self, url: str, headers: Mapping[str, str],
+        data: Optional[Union[bytes, str]], timeout: float,
+        params: Optional[Mapping[str, Union[int, str]]],
+    ) -> Response:
         pass
 
     @abstractmethod
     def put(
-        self, url     , headers                   ,
-        data                            , timeout       ,
-    )            :
+        self, url: str, headers: Mapping[str, str],
+        data: Union[bytes, str, IO[Any]], timeout: float,
+    ) -> Response:
         pass
 
     @abstractmethod
     def delete(
-        self, url     , headers                   ,
-        params                                         ,
-        timeout       ,
-    )            :
+        self, url: str, headers: Mapping[str, str],
+        params: Optional[Mapping[str, Union[int, str]]],
+        timeout: float,
+    ) -> Response:
         pass
 
     @abstractmethod
     def request(
-        self, method     , url     , headers                   ,
-        auto_raise_for_status       = True,
-        **kwargs     
-    )            :
+        self, method: str, url: str, headers: Mapping[str, str],
+        auto_raise_for_status: bool = True,
+        **kwargs: Any
+    ) -> Response:
         pass
 
     @abstractmethod
-    def close(self)        :
+    def close(self) -> None:
         pass
 
 
@@ -108,7 +98,7 @@ if not BUILD_GCLOUD_REST:
 
     Timeout = Union[aiohttp.ClientTimeout, float]
 
-    def _raise_for_status(resp                        )        :
+    def _raise_for_status(resp: aiohttp.ClientResponse) -> None:
         """Check resp for status and if error log additional info."""
         # Copied from aiohttp's raise_for_status() -- since it releases the
         # response payload, we need to grab the `resp.text` first to help users
@@ -134,16 +124,16 @@ if not BUILD_GCLOUD_REST:
             raise aiohttp.ClientResponseError(
                 resp.request_info, resp.history,
                 status=resp.status,
-                message='{}: {}'.format((resp.reason), (body)),
+                message=f'{resp.reason}: {body}',
                 headers=resp.headers,
             )
 
     class AioSession(BaseSession):
-        #_session: aiohttp.ClientSession  # type: ignore[assignment]
-        #_timeout: Timeout  # type: ignore[assignment]
+        _session: aiohttp.ClientSession  # type: ignore[assignment]
+        _timeout: Timeout  # type: ignore[assignment]
 
         @property
-        def session(self)                         :  # type: ignore[override]
+        def session(self) -> aiohttp.ClientSession:  # type: ignore[override]
             if not self._session:
                 connector = aiohttp.TCPConnector(ssl=self._ssl)
 
@@ -159,12 +149,12 @@ if not BUILD_GCLOUD_REST:
             return self._session
 
         def post(  # type: ignore[override]
-            self, url     ,
-            headers                   ,
-            data                                          = None,
-            timeout          = 10,
-            params                                          = None,
-        )                          :
+            self, url: str,
+            headers: Mapping[str, str],
+            data: Optional[Union[bytes, str, IO[AnyStr]]] = None,
+            timeout: Timeout = 10,
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+        ) -> aiohttp.ClientResponse:
             resp = self.session.post(
                 url, data=data, headers=headers,
                 timeout=timeout, params=params,
@@ -173,12 +163,12 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def get(  # type: ignore[override]
-            self, url     ,
-            headers                              = None,
-            timeout          = 10,
-            params                                          = None,
-            stream                 = None,
-        )                          :
+            self, url: str,
+            headers: Optional[Mapping[str, str]] = None,
+            timeout: Timeout = 10,
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+            stream: Optional[bool] = None,
+        ) -> aiohttp.ClientResponse:
             if stream is not None:
                 log.warning(
                     'passed unused argument stream=%s to AioSession: '
@@ -193,11 +183,11 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def patch(  # type: ignore[override]
-            self, url     , headers                   ,
-            data                              = None,
-            timeout          = 10,
-            params                                          = None,
-        )                          :
+            self, url: str, headers: Mapping[str, str],
+            data: Optional[Union[bytes, str]] = None,
+            timeout: Timeout = 10,
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+        ) -> aiohttp.ClientResponse:
             resp = self.session.patch(
                 url, data=data, headers=headers,
                 timeout=timeout, params=params,
@@ -206,10 +196,10 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def put(  # type: ignore[override]
-            self, url     ,
-            headers                   , data                            ,
-            timeout          = 10,
-        )                          :
+            self, url: str,
+            headers: Mapping[str, str], data: Union[bytes, str, IO[Any]],
+            timeout: Timeout = 10,
+        ) -> aiohttp.ClientResponse:
             resp = self.session.put(
                 url, data=data, headers=headers,
                 timeout=timeout,
@@ -218,11 +208,11 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def delete(  # type: ignore[override]
-            self, url     ,
-            headers                   ,
-            params                                          = None,
-            timeout          = 10,
-        )                          :
+            self, url: str,
+            headers: Mapping[str, str],
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+            timeout: Timeout = 10,
+        ) -> aiohttp.ClientResponse:
             resp = self.session.delete(
                 url, headers=headers,
                 params=params, timeout=timeout,
@@ -231,11 +221,11 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def request(  # type: ignore[override]
-            self, method     ,
-            url     , headers                   ,
-            auto_raise_for_status       = True,
-            **kwargs     
-        )                          :
+            self, method: str,
+            url: str, headers: Mapping[str, str],
+            auto_raise_for_status: bool = True,
+            **kwargs: Any
+        ) -> aiohttp.ClientResponse:
             resp = self.session.request(
                 method, url, headers=headers,
                 **kwargs
@@ -244,7 +234,7 @@ if not BUILD_GCLOUD_REST:
                 _raise_for_status(resp)
             return resp
 
-        def close(self)        :
+        def close(self) -> None:
             if not self._shared_session and self._session:
                 self._session.close()
 
@@ -254,11 +244,11 @@ if BUILD_GCLOUD_REST:
         _google_api_lock = threading.RLock()
 
         @property
-        def google_api_lock(self)                   :
+        def google_api_lock(self) -> threading.RLock:
             return SyncSession._google_api_lock  # pylint: disable=protected-access
 
         @property
-        def session(self)           :
+        def session(self) -> Session:
             if not self._session:
                 self._session = Session()
                 self._session.verify = self._ssl
@@ -268,11 +258,11 @@ if BUILD_GCLOUD_REST:
         # symbol ensures we match the base class's definition for static
         # analysis.
         def post(
-            self, url     , headers                   ,
-            data                                          = None,
-            timeout        = 10,
-            params                                          = None,
-        )            :
+            self, url: str, headers: Mapping[str, str],
+            data: Optional[Union[bytes, str, IO[AnyStr]]] = None,
+            timeout: float = 10,
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+        ) -> Response:
             with self.google_api_lock:
                 resp = self.session.post(
                     url, data=data, headers=headers,
@@ -282,11 +272,11 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def get(
-            self, url     , headers                              = None,
-            timeout        = 10,
-            params                                          = None,
-            stream       = False,
-        )            :
+            self, url: str, headers: Optional[Mapping[str, str]] = None,
+            timeout: float = 10,
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+            stream: bool = False,
+        ) -> Response:
             with self.google_api_lock:
                 resp = self.session.get(
                     url, headers=headers, timeout=timeout,
@@ -296,10 +286,10 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def patch(
-            self, url     , headers                   ,
-            data                              = None, timeout        = 10,
-            params                                          = None,
-        )            :
+            self, url: str, headers: Mapping[str, str],
+            data: Optional[Union[bytes, str]] = None, timeout: float = 10,
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+        ) -> Response:
             with self.google_api_lock:
                 resp = self.session.patch(
                     url, data=data, headers=headers,
@@ -309,9 +299,9 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def put(
-            self, url     , headers                   ,
-            data                            , timeout        = 10,
-        )            :
+            self, url: str, headers: Mapping[str, str],
+            data: Union[bytes, str, IO[Any]], timeout: float = 10,
+        ) -> Response:
             with self.google_api_lock:
                 resp = self.session.put(
                     url, data=data, headers=headers,
@@ -321,10 +311,10 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def delete(
-            self, url     , headers                   ,
-            params                                          = None,
-            timeout        = 10,
-        )            :
+            self, url: str, headers: Mapping[str, str],
+            params: Optional[Mapping[str, Union[int, str]]] = None,
+            timeout: float = 10,
+        ) -> Response:
             with self.google_api_lock:
                 resp = self.session.delete(
                     url, params=params, headers=headers,
@@ -334,9 +324,9 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def request(
-            self, method     , url     , headers                   ,
-            auto_raise_for_status       = True, **kwargs     
-        )            :
+            self, method: str, url: str, headers: Mapping[str, str],
+            auto_raise_for_status: bool = True, **kwargs: Any
+        ) -> Response:
             with self.google_api_lock:
                 resp = self.session.request(
                     method, url, headers=headers,
@@ -346,6 +336,6 @@ if BUILD_GCLOUD_REST:
                 resp.raise_for_status()
             return resp
 
-        def close(self)        :
+        def close(self) -> None:
             if not self._shared_session and self._session:
                 self._session.close()
